@@ -4,7 +4,14 @@ from pydicom import dcmread
 from pydicom.errors import InvalidDicomError
 
 XNAT_HIERARCHY = ["Subject", "Session", "Dataset"]
-DICOM_PARAMS = ["Modality", "StudyDescription", "StudyDate"]
+DICOM_PARAMS = [
+    "Modality",
+    "StudyDescription",
+    "StudyDate",
+    "Manufacturer",
+    "ManufacturerModelName",
+    "StationName",
+]
 
 logger = logging.getLogger(__name__)
 
@@ -146,8 +153,8 @@ class Matcher:
                 raise RecipeException(f"Recipe has repeated parameter: {param}")
             if re.match(param[0] + "+$", param):
                 regexp += f"(?P<{param}>" + (r"\d" * len(param)) + ")"
-            elif param == "ID":
-                regexp += f"(?P<{param}>" + r"\d+" + ")"  # for Sublime Text
+            # elif param == "ID":
+            #     regexp += f"(?P<{param}>" + r"\d+" + ")"  # for Sublime Text
             else:
                 if delimiter != "":
                     c = delimiter[0]
@@ -171,10 +178,10 @@ class Matcher:
         """
         label, values = self.match_path(filepath.relative_to(root))
         if label:
-            logger.debug("> reading DICOM metadata")
+            logger.debug(f"> reading DICOM metadata {filepath}")
             dicom_values = self.read_dicom(filepath)
             if dicom_values is None:
-                logger.warning("> couldn't read DICOM metadata ")
+                logger.debug(f"> DICOM read failed {filepath}")
                 match = FileMatch(self, filepath, None)
                 match.status = "No DICOM metadata"
                 return match
@@ -495,3 +502,17 @@ class FileMatch:
             return self.dicom_values["Modality"]
         else:
             return "OT"  # DICOM code for "Other"
+
+    @property
+    def manufacturer(self):
+        if self.dicom_values is not None:
+            return self.dicom_values["Manufacturer"]
+        else:
+            return None
+
+    @property
+    def model(self):
+        if self.dicom_values is not None:
+            return self.dicom_values["ManufacturerModelName"]
+        else:
+            return None
